@@ -1,15 +1,15 @@
 /* eslint-env node */
 
+'use strict'
+
 const path = require('path')
 const ip = require('ip')
-const {
-  browsers,
-  browsersKeys
-} = require('./browsers')
+const { browsers, browsersKeys } = require('./browsers')
 
-const jqueryFile = process.env.USE_OLD_JQUERY ? 'https://code.jquery.com/jquery-1.9.1.min.js' : 'node_modules/jquery/dist/jquery.slim.min.js'
-const bundle = process.env.BUNDLE === 'true'
-const browserStack = process.env.BROWSER === 'true'
+const USE_OLD_JQUERY = Boolean(process.env.USE_OLD_JQUERY)
+const BUNDLE = Boolean(process.env.BUNDLE)
+const BROWSERSTACK = Boolean(process.env.BROWSERSTACK)
+const JQUERY_FILE = USE_OLD_JQUERY ? 'https://code.jquery.com/jquery-1.9.1.min.js' : 'node_modules/jquery/dist/jquery.slim.min.js'
 
 const frameworks = [
   'qunit',
@@ -30,11 +30,15 @@ const detectBrowsers = {
       return ['ChromeHeadless']
     }
 
+    if (availableBrowser.includes('Chromium')) {
+      return ['ChromiumHeadless']
+    }
+
     if (availableBrowser.includes('Firefox')) {
       return ['FirefoxHeadless']
     }
 
-    throw new Error('Please install Firefox or Chrome')
+    throw new Error('Please install Chrome, Chromium or Firefox')
   }
 }
 
@@ -64,7 +68,7 @@ const conf = {
   }
 }
 
-if (bundle) {
+if (BUNDLE) {
   frameworks.push('detectBrowsers')
   plugins.push(
     'karma-chrome-launcher',
@@ -74,15 +78,15 @@ if (bundle) {
   conf.customLaunchers = customLaunchers
   conf.detectBrowsers = detectBrowsers
   files = files.concat([
-    jqueryFile,
+    JQUERY_FILE,
     'dist/js/bootstrap.js'
   ])
-} else if (browserStack) {
+} else if (BROWSERSTACK) {
   conf.hostname = ip.address()
   conf.browserStack = {
     username: process.env.BROWSER_STACK_USERNAME,
     accessKey: process.env.BROWSER_STACK_ACCESS_KEY,
-    build: `bootstrap-${new Date().toISOString()}`,
+    build: `bootstrap-v4-${new Date().toISOString()}`,
     project: 'Bootstrap',
     retryLimit: 2
   }
@@ -94,35 +98,39 @@ if (bundle) {
     'node_modules/jquery/dist/jquery.slim.min.js',
     'js/dist/util.js',
     'js/dist/tooltip.js',
-    'js/dist/!(util|index|tooltip).js' // include all of our js/dist files except util.js, index.js and tooltip.js
+    // include all of our js/dist files except util.js, index.js and tooltip.js
+    'js/dist/!(util|index|tooltip).js'
   ])
 } else {
   frameworks.push('detectBrowsers')
   plugins.push(
     'karma-chrome-launcher',
     'karma-firefox-launcher',
-    'karma-detect-browsers',
-    'karma-coverage-istanbul-reporter'
+    'karma-detect-browsers'
   )
   files = files.concat([
-    jqueryFile,
+    JQUERY_FILE,
     'js/coverage/dist/util.js',
     'js/coverage/dist/tooltip.js',
-    'js/coverage/dist/!(util|index|tooltip).js' // include all of our js/dist files except util.js, index.js and tooltip.js
+    // include all of our js/dist files except util.js, index.js and tooltip.js
+    'js/coverage/dist/!(util|index|tooltip).js'
   ])
-  reporters.push('coverage-istanbul')
   conf.customLaunchers = customLaunchers
   conf.detectBrowsers = detectBrowsers
-  conf.coverageIstanbulReporter = {
-    dir: path.resolve(__dirname, '../coverage/'),
-    reports: ['lcov', 'text-summary'],
-    thresholds: {
-      emitWarning: false,
-      global: {
-        statements: 90,
-        branches: 86,
-        functions: 89,
-        lines: 90
+  if (!USE_OLD_JQUERY) {
+    plugins.push('karma-coverage-istanbul-reporter')
+    reporters.push('coverage-istanbul')
+    conf.coverageIstanbulReporter = {
+      dir: path.resolve(__dirname, '../coverage/'),
+      reports: ['lcov', 'text-summary'],
+      thresholds: {
+        emitWarning: false,
+        global: {
+          statements: 90,
+          branches: 86,
+          functions: 89,
+          lines: 90
+        }
       }
     }
   }
@@ -135,8 +143,7 @@ conf.plugins = plugins
 conf.reporters = reporters
 conf.files = files
 
-module.exports = (karmaConfig) => {
-  // possible values: karmaConfig.LOG_DISABLE || karmaConfig.LOG_ERROR || karmaConfig.LOG_WARN || karmaConfig.LOG_INFO || karmaConfig.LOG_DEBUG
-  conf.logLevel = karmaConfig.LOG_ERROR || karmaConfig.LOG_WARN
+module.exports = karmaConfig => {
+  conf.logLevel = karmaConfig.LOG_ERROR
   karmaConfig.set(conf)
 }
