@@ -41,8 +41,8 @@ $(function () {
 
     try {
       $el.bootstrapToast('noMethod')
-    } catch (err) {
-      assert.strictEqual(err.message, 'No method named "noMethod"')
+    } catch (error) {
+      assert.strictEqual(error.message, 'No method named "noMethod"')
     }
   })
 
